@@ -24,7 +24,7 @@ __all__ = [
     'ColorDetectionUseCase',
     'PPEComplianceUseCase',
     'VehicleMonitoringUseCase',
-    'FireSmokeUseCase'
+    'FireSmokeUseCase',
     'PeopleCountingConfig',
     'CustomerServiceConfig',
     'AdvancedCustomerServiceConfig',
